package com.usky.iot.service.impl;

import com.aliyuncs.DefaultAcsClient;
import com.aliyuncs.IAcsClient;
import com.aliyuncs.dysmsapi.model.v20170525.QuerySendDetailsRequest;
import com.aliyuncs.dysmsapi.model.v20170525.QuerySendDetailsResponse;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsRequest;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsResponse;
import com.aliyuncs.exceptions.ClientException;
import com.aliyuncs.profile.DefaultProfile;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.gson.Gson;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.core.exception.BusinessException;
import com.usky.common.core.util.DateUtils;
import com.usky.common.redis.core.RedisHelper;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.iot.domain.CrmDeviceRepair;
import com.usky.iot.mapper.CrmDeviceRepairMapper;
import com.usky.iot.service.CrmDeviceRepairService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.iot.service.vo.CrmDeviceRepairScoreVO;
import com.usky.iot.service.vo.CrmDeviceRepairVO;
import com.usky.iot.service.vo.PhoneVerifyVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;

/**
 * <p>
 * 设备报修记录表 服务实现类
 * </p>
 *
 * @author han
 * @since 2023-09-06
 */
@Service
public class CrmDeviceRepairServiceImpl extends AbstractCrudService<CrmDeviceRepairMapper, CrmDeviceRepair> implements CrmDeviceRepairService {
    @Autowired
    private RedisHelper redisHelper;

    @Override
    public void add(CrmDeviceRepair crmDeviceRepair){
        crmDeviceRepair.setRepairCode("bx-"+System.currentTimeMillis());
        crmDeviceRepair.setCreateTime(LocalDateTime.now());
        crmDeviceRepair.setRepairStatus(1);
        crmDeviceRepair.setTenantId(SecurityUtils.getTenantId());

        this.save(crmDeviceRepair);


        //发送短信
        StringBuffer sendStatus = new StringBuffer();
        StringBuffer sendContext = new StringBuffer();
        DefaultProfile profile = DefaultProfile.getProfile("cn-beijing", "LTAI5tH3VvRL5BUkovCokHJX", "SaaWUouNqvcA0C746gcNOH9m6SRYN4");
        IAcsClient client = new DefaultAcsClient(profile);
        SendSmsRequest request = new SendSmsRequest();
        request.setPhoneNumbers(crmDeviceRepair.getReflectPhone());//接收短信的手机号码
        request.setSignName("上海永天科技股份有限公司");//短信签名名称
        request.setTemplateCode("SMS_463225651");//短信模板CODE

        request.setTemplateParam("{\"name\":\""+crmDeviceRepair.getReflectName()+"\"}");//短信模板变量对应的实际值

        try {
            SendSmsResponse response = client.getAcsResponse(request);
            if(response.getCode() != null){
                if(response.getCode().equals("OK")){
//                    sendStatus.append("1");
//                    //查询发送短信内容
//
//                    try {
//                        Thread.sleep(3000);
//                    } catch (InterruptedException e) {
//                        e.printStackTrace();
//                    }
//
//                    QuerySendDetailsRequest request1 = new QuerySendDetailsRequest();
//                    request1.setPhoneNumber(crmDeviceRepair.getReflectPhone());
//                    request1.setSendDate(LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd")));
//                    request1.setPageSize((long)10);
//                    request1.setCurrentPage((long)1);
//                    QuerySendDetailsResponse response1 = client.getAcsResponse(request1);
//                    if(response1.getCode() != null){
//                        if(response1.getCode().equals("OK")){
//                            sendContext.append(response1.getSmsSendDetailDTOs().get(0).getContent());
//                        }
//
//                    }

                }else{
//                    sendStatus.append("2");
                }
            }
            System.out.println(new Gson().toJson(response));
        } catch (ClientException e) {
            System.out.println("ErrCode:" + e.getErrCode());
            System.out.println("ErrMsg:" + e.getErrMsg());
            System.out.println("RequestId:" + e.getRequestId());
        }

    }

    @Override
    public CommonPage<CrmDeviceRepair> page(CrmDeviceRepairVO crmDeviceRepairVO){
        IPage<CrmDeviceRepair> page = new Page<>(crmDeviceRepairVO.getCurrent(),crmDeviceRepairVO.getSize());
        LambdaQueryWrapper<CrmDeviceRepair> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(StringUtils.isNotBlank(crmDeviceRepairVO.getProjectName()),CrmDeviceRepair::getProjectName,crmDeviceRepairVO.getProjectName())
                .like(StringUtils.isNotBlank(crmDeviceRepairVO.getReflectName()),CrmDeviceRepair::getReflectName,crmDeviceRepairVO.getReflectName())
                .eq(crmDeviceRepairVO.getRepairStatus() != null,CrmDeviceRepair::getRepairStatus,crmDeviceRepairVO.getRepairStatus())
                .between(StringUtils.isNotBlank(crmDeviceRepairVO.getStartTime()) && StringUtils.isNotBlank(crmDeviceRepairVO.getEndTime()),CrmDeviceRepair::getCreateTime,crmDeviceRepairVO.getStartTime(),crmDeviceRepairVO.getEndTime())
                .orderByDesc(CrmDeviceRepair::getId);
        page = this.page(page,queryWrapper);

        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getSize(),page.getCurrent());

    }

    @Override
    public void fill(CrmDeviceRepair crmDeviceRepair1){
        crmDeviceRepair1.setRepairStatus(2);
        crmDeviceRepair1.setHandleTime(LocalDateTime.now());
        this.updateById(crmDeviceRepair1);

        CrmDeviceRepair crmDeviceRepair = this.getById(crmDeviceRepair1.getId());

        //发送短信
        StringBuffer sendStatus = new StringBuffer();
        StringBuffer sendContext = new StringBuffer();
        DefaultProfile profile = DefaultProfile.getProfile("cn-beijing", "LTAI5tH3VvRL5BUkovCokHJX", "SaaWUouNqvcA0C746gcNOH9m6SRYN4");
        IAcsClient client = new DefaultAcsClient(profile);
        SendSmsRequest request = new SendSmsRequest();
        request.setPhoneNumbers(crmDeviceRepair.getReflectPhone());//接收短信的手机号码
        request.setSignName("上海永天科技股份有限公司");//短信签名名称
        request.setTemplateCode("SMS_463206001");//短信模板CODE

        String custom = "#/pages/common/evaluate/index?statusBool=true&repairCode="+crmDeviceRepair.getRepairCode();
        request.setTemplateParam("{\"name\":\""+crmDeviceRepair.getReflectName()+"\","+"\"date\":\""+crmDeviceRepair.getCreateTime().format(DateTimeFormatter.ofPattern("yyyy-MM-dd"))+"\","+"\"custom\":\""+custom+"\"}");//短信模板变量对应的实际值

        try {
            SendSmsResponse response = client.getAcsResponse(request);
            if(response.getCode() != null){
                if(response.getCode().equals("OK")){
//                    sendStatus.append("1");
//                    //查询发送短信内容
//
//                    try {
//                        Thread.sleep(3000);
//                    } catch (InterruptedException e) {
//                        e.printStackTrace();
//                    }
//
//                    QuerySendDetailsRequest request1 = new QuerySendDetailsRequest();
//                    request1.setPhoneNumber(crmDeviceRepair.getReflectPhone());
//                    request1.setSendDate(LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd")));
//                    request1.setPageSize((long)10);
//                    request1.setCurrentPage((long)1);
//                    QuerySendDetailsResponse response1 = client.getAcsResponse(request1);
//                    if(response1.getCode() != null){
//                        if(response1.getCode().equals("OK")){
//                            sendContext.append(response1.getSmsSendDetailDTOs().get(0).getContent());
//                        }
//
//                    }

                }else{
//                    sendStatus.append("2");
                }
            }
            System.out.println(new Gson().toJson(response));
        } catch (ClientException e) {
            System.out.println("ErrCode:" + e.getErrCode());
            System.out.println("ErrMsg:" + e.getErrMsg());
            System.out.println("RequestId:" + e.getRequestId());
        }

    }

    @Override
    public void score(CrmDeviceRepairScoreVO scoreVO){
        LambdaQueryWrapper<CrmDeviceRepair> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(CrmDeviceRepair::getRepairCode,scoreVO.getRepairCode());
        CrmDeviceRepair crmDeviceRepair = this.getOne(queryWrapper);

        crmDeviceRepair.setScore(scoreVO.getScore());
        crmDeviceRepair.setAppraiseContent(scoreVO.getAppraiseContent());
        this.updateById(crmDeviceRepair);
    }

    @Override
    public void phoneVerify(PhoneVerifyVO phoneVerifyVO){
        String phone = phoneVerifyVO.getPhone();
        String verify = phoneVerifyVO.getVerify();
        if(!com.usky.common.core.util.StringUtils.isBlank(phone) && !com.usky.common.core.util.StringUtils.isBlank(verify)) {
            //手机验证码登录
            if (com.usky.common.core.util.StringUtils.isBlank(verify)) {
                throw new BusinessException("验证码不能为空");
            }
            if (!verify.equals(redisHelper.get(phone))) {
                throw new BusinessException("验证码错误");
            }
            if (com.usky.common.core.util.StringUtils.isBlank(phone)) {
                throw new BusinessException("用户名或手机号不能为空");
            }
        }
    }

    @Override
    public CommonPage<CrmDeviceRepair> getHistory(PhoneVerifyVO phoneVerifyVO){
        String phone = phoneVerifyVO.getPhone();

        IPage<CrmDeviceRepair> page = new Page<>(phoneVerifyVO.getCurrent(), phoneVerifyVO.getSize());
        LambdaQueryWrapper<CrmDeviceRepair> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(CrmDeviceRepair::getReflectPhone,phone)
                .orderByDesc(CrmDeviceRepair::getId);
        page = this.page(page,queryWrapper);

        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getSize(),page.getCurrent());
    }
}
